#
# spec file for package rust-cbindgen
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use hardening ldflags.
%global crate_name cbindgen
%global rustflags -Clink-arg=-Wl,-z,relro,-z,now
Name:           rust-%{crate_name}
Version:        0.14.1
Release:        bp153.2.6
Summary:        A tool for generating C bindings from Rust code
License:        MPL-2.0
Group:          Development/Languages/Rust
URL:            https://crates.io/crates/cbindgen
Source0:        https://github.com/eqrion/cbindgen/archive/v%{version}.tar.gz#/%{crate_name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo >= 1.32.0
BuildRequires:  rust >= 1.32.0
BuildRequires:  rust-std-static >= 1.32.0

%description
A tool for generating C bindings from Rust code.

%prep
%setup -q -T -b 0 -n %{crate_name}-%{version}
%setup -q -D -T -a 1 -n %{crate_name}-%{version}
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
# This should eventually migrate to distro policy
# Enable optimization, debuginfo, and link hardening.
export RUSTFLAGS="%{rustflags}"
export CARGO_HOME=`pwd`/cargo-home/

cargo build --release

%install
# rustflags must be exported again at install as cargo build will
# rebuild the project if it detects flags have changed (to none or other)
export RUSTFLAGS="%{rustflags}"
# install stage also requires re-export of 'cargo-home' or cargo
# will try to download source deps and rebuild
export CARGO_HOME=`pwd`/cargo-home/
# cargo install appends /bin to the path
cargo install --root=%{buildroot}%{_prefix} --path .
# remove spurious files
rm -f %{buildroot}%{_prefix}/.crates.toml
rm -f %{buildroot}%{_prefix}/.crates2.json

%files
%license LICENSE
%{_bindir}/cbindgen

%changelog
* Wed Apr 15 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- update to version 0.14.1
  * Handle mangling pointers.
  * Unconditionally generate a return statement in partialeq
    implementations.
- update to version 0.14.0
  * Minor tweak at how [export.exclude] is handled to allow
    excluding generic instantiations in C mode.
  * Documented cpp_compat option.
  * Fixed a panic when parsing associated constants for a
    built-in type.
- update to version 0.13.2
  * Constants now have suitable documentation.
  * Fixed some C warnings by emitting void when there are
    no arguments.
  * Avoids reading cargo.toml when not needed, which can cause
    panics in workspace situations.
  * Only write `default` cases if the switch is not exhaustive.
  * Some warnings have been refined.
  * Code generation for static arrays has been fixed.
  * Opt-in support for constexpr in constants.
  * Fix C code generation and some warnings when extremely
    large constants are used.
  * Proper escaping of enum variants and fields.
  * Added support for RefCell (as an opaque type) and Cell.
* Thu Feb 27 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- update to version 0.13.1
  * Support `#[cfg]` on individual enum variants.
- update to version 0.13.0
  * Support 'swift_name' attributes on generated functions
  * Add [export.pre_body] to config
  * Handle new line in doc attribute
  * Add support for `Self` in tagged enums, structs and unions
  * Make sentinel variant respect regular config
  * Fix layout of tagged enums with size under some configurations
  * Add an option to allow configuring the order of function names
    in generated headers
* Fri Jan 17 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- update to version 0.12.2
  * Fixed version detection with lockfile v2.
  * Added support for export_name on functions.
- update to version 0.12.1
  * Added support for #[repr*64)] on enums.
  * Added support to generate plain enums instead of enum
    classes for C++.
  * Fixed dependency resolution with lockfile v2.
- update to version 0.12.0
  * Added support for #[repr(align)] and #[repr(packed)] on
    structs and unions.
  * Added support to generate copy-assignment operators for
    enums.
- update to version 0.11.1
  * More binary operators and expressions are supported.
  * More built-in bitflags operators.
- update to version 0.11.0
  * Made rust char map to uint32_t.
- update to version 0.10.1
  * Improved error message for missing config file.
  * Add missing header for char32_t.
- update to version 0.10.0
  * Initialize struct literal with list-initializer for C++11
    standard.
  * Surround namespace with __cplusplus ifdef in cpp_compat
    mode.
  * Add support for --quiet flag.
  * Map char to char32_t.
  * Improve binding_crate_ref() error message.
  * avoid prematurely returning during expansion.
  * Add support for adding "using namespace" statements.
* Fri Oct 18 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- Update to version 0.9.1
  * Various improvements to comment output.
  * Fixed expand when ran from build.rs.
  * More debugging output for expansion.
  * New option to add a default private constructor in C++ tagged enums.
  * Syn and related dependencies updated to 1.0.
* Thu Aug  8 2019 Luke Jones <luke@ljones.dev>
- Update to version 0.9.0
  * Support to generate C headers with C++ compatibility
  * Fix include guard generation when no_includes is set
  * Fix crate parsing order so that types from the binding crate
    are preferred in presence of conflicting names
  * Add extra_bindings option to generate bindings for dependencies
  * Clap dependency is optional now so it's feasible to avoid
    building it if cbindgen is used as a library
* Tue May 14 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- update to version 0.8.7
  * there is no upstream changelog provided
* Sun Mar 17 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- update to version 0.6.8 to satisfy Firefox 66.0 build requirements
* Mon Nov 19 2018 astieger@suse.com
- use a source URL
* Wed Nov 14 2018 Luke Jones <jones_ld@protonmail.com>
- Initial packaging - boo#1115645
